==> openshift-client-4.13.2-sources.jar: io/fabric8/openshift/client/handlers/InstallPlanHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.InstallPlanOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan;
import io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class InstallPlanHandler implements ResourceHandler<InstallPlan, InstallPlanBuilder> {

  @Override
  public String getKind() {
    return InstallPlan.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operators.coreos.com/v1alpha1";
    }

  @Override
  public InstallPlan create(OkHttpClient client, Config config, String namespace, InstallPlan item) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public InstallPlan replace(OkHttpClient client, Config config, String namespace, InstallPlan item) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public InstallPlan reload(OkHttpClient client, Config config, String namespace, InstallPlan item) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public InstallPlanBuilder edit(InstallPlan item) {
    return new InstallPlanBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, InstallPlan item) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, InstallPlan item, Watcher<InstallPlan> watcher) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, InstallPlan item, String resourceVersion, Watcher<InstallPlan> watcher) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, InstallPlan item, ListOptions options, Watcher<InstallPlan> watcher) {
  return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public InstallPlan waitUntilReady(OkHttpClient client, Config config, String namespace, InstallPlan item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public InstallPlan waitUntilCondition(OkHttpClient client, Config config, String namespace, InstallPlan item, Predicate<InstallPlan> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.2.0-sources.jar: io/fabric8/openshift/client/handlers/InstallPlanHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.InstallPlanOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlan;
import io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class InstallPlanHandler implements ResourceHandler<InstallPlan, InstallPlanBuilder> {

  @Override
  public String getKind() {
    return InstallPlan.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operators.coreos.com/v1alpha1";
    }

  @Override
  public InstallPlan create(OkHttpClient client, Config config, String namespace, InstallPlan item, boolean dryRun) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public InstallPlan replace(OkHttpClient client, Config config, String namespace, InstallPlan item, boolean dryRun) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public InstallPlan reload(OkHttpClient client, Config config, String namespace, InstallPlan item) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public InstallPlanBuilder edit(InstallPlan item) {
    return new InstallPlanBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, InstallPlan item, boolean dryRun) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, InstallPlan item, Watcher<InstallPlan> watcher) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, InstallPlan item, String resourceVersion, Watcher<InstallPlan> watcher) {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, InstallPlan item, ListOptions options, Watcher<InstallPlan> watcher) {
  return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public InstallPlan waitUntilReady(OkHttpClient client, Config config, String namespace, InstallPlan item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public InstallPlan waitUntilCondition(OkHttpClient client, Config config, String namespace, InstallPlan item, Predicate<InstallPlan> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new InstallPlanOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
